<?php
global $post, $eventbrite_music;
$settings = $eventbrite_music->get_options();

$events     = ( ! empty( $events ) ) ? $events : [];
$pagination = ( $ebApiData->get_pagination() ) ? $ebApiData->get_pagination() : [];
$eventCount = count($events);

extract( wp_parse_args( $atts, [
	'imagesize'           => 'small',
	'timezone'            => '',
	'dateformat'          => 'D n/d',
	'title'               => 'Upcoming Shows',
	'exclude'             => '',
	'include'             => '',
	'page'                => '',
	'calshare'            => 'true',
	'num'                 => '50',
	'venue'               => '',
	'org'                 => '',
	'excludevenue'        => '',
	'type'                => '',
] ) );

$exclude   = explode( ",", $exclude );
$include   = explode( ",", $include );
$is_search = isset( $_GET[ 'q' ] );

if ( $is_search ) {
	$searchQuery = sanitize_text_field( $_GET[ 'q' ] );
}
?>
<article class="list-view <?php if ( $is_search ) {
	echo 'search-results';
						  } ?>">

	<div class="list-view-heading">
		<?php if ( ! in_array( "list-view-title", $exclude, true ) ) { ?>
			<h2 class="list-view-title">
				<?php
				if ( $is_search ) {
					if ( $searchQuery === 'Enter an Artist, Event, City or Venue' ) {
						esc_html_e( 'Looking for something? Use the box above.', 'eventbrite' );
					} else {
						esc_html_e( 'Search results', 'eventbrite' );
					}
				} else {
					echo esc_html( $title );
				}
				?>
			</h2>
		<?php } // end of title exclusion if statement

		if ( ! in_array( "calendar-link", $exclude, true ) ) { ?>
			<h2 class="calendar-link">
			<a class="calendar" href="<?php
			if ( isset( $post->eb_type ) ) {
				echo esc_url( eb_URL( 'calendar', $post->primary_organizer_id, $post->eb_type ) );
			} else {
				echo esc_url( eb_URL( 'calendar' ) );
			}
			?>"><?php esc_html_e( 'View Calendar', 'eventbrite' ); ?></a>
			</h2><?php
		} ?>

	</div>
	<?php if ( is_integer( $eventCount ) && ( $eventCount > 0 ) ) {

		//if we're doing a search result we need some additional text
		if ( $is_search ) { ?>
			<div class="search-results-message">
				<?php
				$searchResultsText = sprintf(
					_n(
						'%d search result for &ldquo;%s&rdquo;',
						'%d search results for &ldquo;%s&rdquo;',
						$eventCount,
						'eventbrite' 
					),
					number_format_i18n( $eventCount ),
					esc_html( $searchQuery )
				);
				echo esc_html( $searchResultsText ); ?>
			</div>
		<?php }

		//we have an events listing.  do the loop
		$templPathList = eb_locate_template( '/list-view-item' );
		foreach ( $events as $count => $event ) {
			$urlVars       = eb_getInitialUrlVars( $event );
			$templPath     = $templPathList;
			$templateClass = 'listview';
			$urlClasses    = 'event-url';
			$data_values      = eb_locate_template( '/event-data-values' );
			if ( ! empty( $data_values ) ) {
				require $data_values;
			}
			$performers = new Performers();
			$performancesMarkup = $performers->build_Listview_Performers( $event, $edpUrl, $exclude );
			if ( ! empty( $templPath ) ) {
				require $templPath;
			}
			$urlVars = null;
		} // end event loop

	} elseif ( isset($searchQuery) && $searchQuery === 'Enter an Artist or Event' ) {
		//user pressed enter without using the search box
		?><br/><?php
	} elseif ( $is_search ) {
		//we're performing a search, but there are no matching search results
		?>
		<div class="search-results-message">
			<p><b>No results found for &ldquo;<?php echo esc_html( $searchQuery ); ?>&rdquo;.</b></p>
			<p>We're sorry, but we couldn't find any events for
				&ldquo;<?php echo esc_html( $searchQuery ); ?>&rdquo;.
				Please check your spelling and punctuation and try again using the search box above. </p>
		</div>
	<?php } else {
		//no events were returned in the events listing ?>
		<h3 class="event-status-message">
			<?php if ( false !== strpos( $type, 'onsale' ) ) {
				esc_html_e( 'No upcoming on sales. Check back soon.', 'eventbrite' );
			} else {
				eb_generate_no_events_status_message();
			} ?>
		</h3>
	<?php }

	eb_listview_pagination( $pagination, $exclude ); ?>

</article>
