<?php

class Performers {
	const EB_CAROUSEL_TRUNCATE = 40;
	/********************* PUBLIC **********************/

	public function build_Listview_Performers( $event, $edpUrl, $exclude, $mobile = false ) {
		if ( ! $event->top_performances || ! $this->event_has_headliners( $event->top_performances ) ) {
			return $this->list_EventName( $event, $edpUrl );
		}

		$performances = $event->top_performances;

		$comma_supports = $this->comma_performanceRoles( $event, 'supporter' );
		$supports       = $this->add_andMore( count($performances), $edpUrl, '' );

		if ( $comma_supports !== false && $this->list_exclude( $exclude ) !== true ) {
			$andMore      = $this->add_andMore( count($performances), false, ', ' );
			$support_list = $comma_supports . $andMore;
			$addedHref    = $this->addHref( $support_list, $edpUrl );
			$supports     = $this->addMarkup( $addedHref, 'supporter' );
		}

		if ( $this->is_option_one( $event ) ) {
			return $this->display_option_one_title( $event, $edpUrl, $mobile ) . $supports;
		}

		$markup = '';
		if ( $mobile ) {
			$markup .= $this->addH1( $this->comma_performanceRoles( $event, 'headliner' ) );
		} else {
			$markup .= $this->list_performanceRoles( $performances, 'headliner', $edpUrl );
		}


		$markup .= $supports;

		return $markup;
	}

	public function build_Calendar_Performers( $event, $edpUrl, $exclude, $mobile = false ) {
		if ( empty( $event->top_performances ) || ! $this->event_has_headliners( $event->top_performances ) ) {
			return $this->list_EventName( $event, $edpUrl );
		}

		$performances = $event->top_performances;

		$supports = '';
		if ( $this->list_exclude( $exclude ) !== true ) {
			$supports = $this->list_performanceRoles( $performances, 'supporter', $edpUrl );
		}
		$andMore = $this->add_andMore( count($performances), $edpUrl, '' );
		if ( $andMore !== '' ) {
			$andMore = $this->addMarkup( $andMore, 'supporter' );
		}

		if ( $this->is_option_one( $event ) ) {
			return $this->display_option_one_title( $event, $edpUrl, $mobile ) . $supports . $andMore;
		}

		$markup = '';
		if ( $mobile ) {
			$markup .= $this->addH1( $this->comma_performanceRoles( $event, 'headliner' ) );
		} else {
			$markup .= $this->list_performanceRoles( $performances, 'headliner', $edpUrl );
		}


		$markup .= $supports;

		$markup .= $andMore;

		return $markup;
	}

	public function build_EDP_Performers( $event, $performances, $exclude ) {
		if ( empty( $performances ) || ! $this->event_has_headliners( $performances ) ) {
			return $this->list_EventName( $event, false );
		}

		if ( empty( $performances ) ) {
			return $this->list_EventName( $event, false );
		}

		$supports       = '';
		$comma_supports = $this->comma_performanceRoles( $event, 'supporter' );
		if ( $comma_supports !== false && $this->list_exclude( $exclude ) !== true ) {
			$supports = $this->addMarkup( $comma_supports, 'supporter' );
		}
		if ( $this->is_option_one( $event ) ) {
			$event->top_performances = $performances;

			return $this->display_option_one_title( $event, false ) . $supports;
		}
		$markup = '';
		$markup .= $this->list_performanceRoles( $performances, 'headliner', false );
		$markup .= $supports;

		return $markup;
	}

	public function build_comma_eventName( $event, $role ) {
		if ( ! $event->top_performances ) {
			return $event->name->text;
		}
		$markup = $this->comma_performanceRoles( $event, $role );

		return $markup;
	}

	public function build_carousel_eventName( $event, $edpUrl, $exclude ) {
		if ( in_array( 'headliners', (array) $exclude, true ) ) {
			return;
		}
		$headliners = $this->comma_performanceRoles( $event, 'headliner' );
		if ( $this->is_option_one( $event ) && $headliners !== $event->name->text ) {
			$truncated = $this->truncate( $event->name->text );
			$addedHref = $this->addHref( $truncated, $edpUrl );

			return $this->addH1( $addedHref );
		}

		$comma_eventName = $this->build_comma_eventName( $event, 'headliner' );
		$truncated       = $this->truncate( $comma_eventName );
		$addedHref       = $this->addHref( $truncated, $edpUrl );

		return $this->addH1( $addedHref );
	}

	public function get_event_headline( $event ) {
		$headliners = $this->comma_performanceRoles( $event, 'headliner' );
		if ( $this->is_option_one( $event ) && $headliners !== $event->name->text ) {
			return $event->name->text;
		}

		return $headliners;
	}

	public function truncate( $eventName ) {
		if ( strlen( $eventName ) < self::EB_CAROUSEL_TRUNCATE ) {
			return $eventName;
		} else {
			return mb_substr( $eventName, 0, self::EB_CAROUSEL_TRUNCATE, "utf-8" ) . "...";
		}
	}

	/********************* PRIVATE **********************/

	protected function display_option_one_title( $event, $edpURL, $mobile = false ) {

		$headliners = $this->comma_performanceRoles( $event, 'headliner' );
		if ( $headliners === $event->name->text ) {
			if ( $mobile ) {
				return $this->addH1( $headliners );
			}

			return $this->list_performanceRoles( $event->top_performances, 'headliner', $edpURL );
		}

		return $this->list_EventName( $event, $edpURL );
	}

	protected function is_option_one( $event ) {
		return isset( $event->top_performers );
	}

	private function list_exclude( $exclude ) {
		if ( in_array( 'supports', (array) $exclude, true ) ) {
			return true;
		}
	}

	private function list_performanceRoles( $performances, $role, $edpUrl ) {
		$allPerformers = [];
		foreach ( $performances as $performer ) {
			if ( $performer->performer_role === $role && eb_is_valid_field( $performer->display_name ) ) {
				$performerItem   = ( $edpUrl !== false ) ? $this->addHref(
					$performer->display_name,
					$edpUrl 
				) : $performer->display_name;
				$allPerformers[] = $performerItem;
			}
		}
		$markup = '';
		$num    = 0;
		if ( ( $role === 'headliner' ) ) {
			$markup .= $this->addH1( $allPerformers[ 0 ] );
			$num    = 1;
		}

		for ( $i = $num; $i < count( $allPerformers ); ++ $i ) {
			$markup .= $this->addMarkup( $allPerformers[ $i ], $role );
		}

		return $markup;
	}

	/**
	 * Checks if there are headliner types in the top performances
	 *
	 * @param $performances
	 *
	 * @return bool
	 */
	private function event_has_headliners( $performances ) {
		foreach ( $performances as $performance ) {
			if ( $performance->performer_role === 'headliner' && eb_is_valid_field( $performance->display_name ) ) {
				return true;
			}
		}

		return false;
	}

	private function list_EventName( $event, $edpUrl ) {
		$eventName = ( $edpUrl !== false ) ? $this->addHref( $event->name->text, $edpUrl ) : $event->name->text;
		$markup    = $this->addH1( $eventName );

		return $markup;
	}

	private function comma_performanceRoles( $event, $role ) {
		$performerArray = $this->get_performances_by_role( $event, $role );
		if ( empty( $performerArray ) && $role === 'headliner' ) {
			return $event->name->text;
		}
		if ( empty( $performerArray ) && $role === 'supporter' ) {
			return false;
		}
		$markup = implode( ", ", (array) $performerArray );

		return $markup;
	}

	protected function get_performances_by_role( $event, $role ) {
		$top_performances = $event->top_performances;
		$performances     = !empty($top_performances) ? $top_performances : [];
		$performerArray   = [];
		foreach ( $performances as $h ) {
			if ( $h->performer_role === $role && eb_is_valid_field( $h->display_name ) ) {
				$performerArray[] = trim( $h->display_name );
			}
		}

		return $performerArray;
	}

	private function addHref( $performer, $edpUrl ) {
		if ( $edpUrl === false ) {
			return $performer;
		}

		return '<a href="' . $edpUrl . '">' . $performer . '</a>';
	}

	private function addH1( $performer ) {
		return '<h1 class="event-name headliners">' . $performer . '</h1>';
	}

	private function addMarkup( $performer, $role ) {
		$h     = 'h1';
		$class = 'headliners';
		if ( $role === 'supporter' ) {
			$h     = 'h2';
			$class = 'supports';
		}
		$markup = '<' . $h . ' class="' . $class . '">' . $performer . '</' . $h . '>';

		return $markup;
	}

	private function add_andMore( $total, $edpUrl, $comma ) {
		$andMore = '';
		if ( $total && $total > 6 ) {
			$andMore = '<span class="and-more">' . $comma . 'and more</span>';

			if ( $edpUrl !== false ) {
				$andMore = $this->addHref( $andMore, $edpUrl );
			}
		}

		return $andMore;
	}

}
