<?php
/*
Plugin Name: Eventbrite Mobile - Public
Version: 2.0.0
Plugin URL: https://www.eventbrite.com
Description: A plugin to display events (and blog posts) for mobile devices
Author: Marco Schmoecker
URL: https://www.eventbrite.com
*/

register_activation_hook( __FILE__, 'eventbrite_mobile_activate' );
function eventbrite_mobile_activate() {
	// Require parent plugin
	if ( ! is_plugin_active( 'eventbrite-events-public/eb-events.php' ) ) {
		// Stop activation redirect and show error
		wp_die( 'Sorry. The Eventbrite Mobile plugin requires the Eventbrite Events - Public API Version plugin to be active.' );
	}
}

define( 'EB_MB_VERSION', '2.0.0' );
$dependencies = [
	WP_PLUGIN_DIR . '/eventbrite-events-public/includes/api/Events_Api.php',
	WP_PLUGIN_DIR . '/eventbrite-events-public/includes/api/Event_Api.php',
	WP_PLUGIN_DIR . '/eventbrite-events-public/includes/api/Oauth.php',
	WP_PLUGIN_DIR . '/eventbrite-events-public/includes/api/Performer_Api.php',
	WP_PLUGIN_DIR . '/eventbrite-events-public/includes/api/Description_Api.php',
	dirname( __FILE__ ) . '/libs/Mobile_Detect.php',
	dirname( __FILE__ ) . '/eb_functions.php',
	dirname( __FILE__ ) . '/theme_setup.php',
];

foreach ( $dependencies as $dependency ) {
	if ( file_exists( $dependency ) ) {
		require_once( $dependency );
	}
}


if ( ! class_exists( 'eventbrite_mobile' ) ) :

	class eventbrite_mobile {
		public $id = 'eventbrite_mobile_v2';

		/**
		 * @var string Version of the generator in SVN
		 */
		private static $svnVersion = '2.0';
		/**
		 * The key to use for the options and all input/id prefixes
		 *
		 * @var string the site option key
		 */
		public $settings_ref = 'eventbrite_mobile_v1';

		/**
		 * The key to use for the options and all input/id prefixes
		 *
		 * @var string the site option key
		 */
		public $device = '';

		/**
		 * Client sites are able to overwrite default CSS styles
		 *
		 * @var string URL to CSS file to overwrite plugin defaults
		 */
		public $client_css_overwrite = '';

		/**
		 * @var array
		 */
		protected $cms_settings = [];


		function cleanup_shortcode_fix( $content ) {
			$array   = [
				'<p>['    => '[',
				']</p>'   => ']',
				']<br />' => ']',
				']<br>'   => ']',
			];
			$content = strtr( $content, $array );

			return $content;
		}

		// returns the content of $GLOBALS['post']
		// if the page is called 'debug'
		function maybe_display_listview_default( $content ) {
			if ( get_query_var( 'is_eb_forced_front', 0 ) ) {
				return do_shortcode( '[eb_listview]' );
			}

			// otherwise returns the database content
			return $content;
		}

		function force_front_page_blog_site( WP_Query $wp_query ) {
			if ( $wp_query->is_main_query() && 'posts' === get_option( 'show_on_front' ) && $wp_query->is_home() ) {
				set_query_var( 'is_home', false );
				$wp_query->is_home = false;
				set_query_var( 'is_page', true );
				$wp_query->is_page = true;
				set_query_var( 'is_eb_forced_front', true );

				return $wp_query;
			}

			return $wp_query;
		}

		function maybe_force_cycloneslider_responsive( $out, $pairs, $atts ) {
			$out[ 'template' ] = 'responsive';

			return $out;
		}

		public function the_posts_replace_forced_front( $posts ) {
			if ( is_main_query()
			     && 'page' === get_option( 'show_on_front' ) && get_option( 'page_on_front' ) && isset( $posts[ 0 ]->ID ) && ( $posts[ 0 ]->ID === get_option( 'page_on_front' ) )
			     && ( count( $posts ) === 1 )
			     && isset( $posts[ 0 ]->post_content ) && empty( $posts[ 0 ]->post_content ) ) {
				set_query_var( 'is_eb_forced_front', true );
			}

			if ( '' === get_query_var( 'is_eb_forced_front', '' ) ) {
				return $posts;
			}

			$defPost = [
				new  WP_Post( (object) [
					'id'           => '1',
					'post_title'   => 'front',
					'post_content' => '[eb_listview]',
				] ),
			];

			return $defPost;
		}


		function __construct() {
			$this->defaults = [
				'desktop_destination_url' => "",
				'theme_color'             => "light",
				'type_kit'                => "",
			];

			add_action( 'init', [ $this, 'init' ] );
			add_action( 'init', [ $this, 'action_handler' ] );
			add_action( 'admin_menu', [ $this, 'admin_menu' ] );
			add_action( 'admin_init', [ $this, 'admin_page_init' ] );

			add_action( 'wp_ajax_eb-mobile-cal-ajax', [ $this, 'cal_ajax_func' ] );
			add_action( 'wp_ajax_nopriv_eb-mobile-cal-ajax', [ $this, 'cal_ajax_func' ] );
			add_action( 'wp_ajax_eb-listing-ajax', [ $this, 'listing_ajax_func' ] );
			add_action( 'wp_ajax_nopriv_eb-listing-ajax', [ $this, 'listing_ajax_func' ] );
			add_action( 'wp_ajax_tfly-slider-ajax', [ $this, 'slider_ajax_func' ] );
			add_action( 'wp_ajax_nopriv_tfly-slider-ajax', [ $this, 'slider_ajax_func' ] );

			$this->device = $this->mobile_check();

			add_shortcode( 'tf_mobile', [ $this, 'eb_mobile_func' ] );
			add_shortcode( 'eb_mobile', [ $this, 'eb_mobile_func' ] );
			add_shortcode( 'tf_desktop', [ $this, 'eb_desktop_func' ] );
			add_shortcode( 'eb_desktop', [ $this, 'eb_desktop_func' ] );
			add_filter( 'eb_mobile_tag', [ $this, 'eb_mobile_tag_filter' ] );

			if ( ! is_admin() && $this->device ) {
				// old deployment file
				remove_filter( 'eb_mobile_tag', [ $this, 'eb_mobile_tag_filter' ] );
				add_filter( 'eb_desktop_tag', [ $this, 'eb_mobile_tag_filter' ] );
				add_filter( 'body_class', 'eb_add_slug_body_class' );
				$eb_mobileOptions = $this->get_options();
				add_filter( 'the_posts', [ $this, 'the_posts_replace_forced_front' ], 1 );
				add_filter( 'the_content', [ $this, 'cleanup_shortcode_fix' ] );
				add_filter( 'the_content', [ $this, 'maybe_display_listview_default' ], 20 );
				add_action( 'pre_get_posts', [ $this, 'force_front_page_blog_site' ] );
				add_filter( 'shortcode_atts_cycloneslider', [ $this, 'maybe_force_cycloneslider_responsive' ], 10, 3 );
				define( 'EB_MOBILE_THEME', '../plugins/' . basename( dirname( __FILE__ ) ) . '/theme' );

				if ( ! defined( 'WP_USE_THEMES' ) ) {
					define( 'WP_USE_THEMES', true );
				}

				add_filter( 'query_vars', [ $this, 'query_vars' ] );

				//todo: do we need to move our mobile theme filters into an action? that way we don't need to save the orig. theme's path....
				$this->orig_theme_uri = get_stylesheet_directory_uri();
				$this->orig_theme_dir = get_stylesheet_directory();

				add_filter( 'stylesheet_uri', [ $this, 'mobile_stylesheet_fixpath' ] );
				add_filter( 'stylesheet', [ $this, 'mobile_stylesheet' ] );
				add_filter( 'template', [ $this, 'mobile_template' ] );
				add_filter( 'eb_template', [ $this, 'mobile_eb_cms_template' ], 10, 2 );

				add_action( 'wp_enqueue_scripts', [ $this, 'eb_mobile_scripts' ] );
				add_action( 'wp_enqueue_scripts', [ $this, 'eb_mobile_styles' ] );
				add_action( 'wp_head', [ $this, 'favicon' ], 5 );

				add_shortcode( 'eb_slider', [ $this, 'eb_slider_func' ] );
				add_filter( 'widget_text', 'do_shortcode' );
			}
		}

		function eb_mobile_styles() {
			wp_enqueue_style( 'style', get_stylesheet_uri(), '', EB_MB_VERSION );
			$inlineLogoCSS = $this->inline_legacy_logo_css();
			if ( $inlineLogoCSS ) {
				wp_add_inline_style( 'style', $inlineLogoCSS );
			}
			wp_enqueue_style( 'eb-mobile-venue' );
			wp_dequeue_style( 'fbComments_displayRsvpCss' );
			wp_dequeue_style( 'ebStyleSheets' );
			wp_dequeue_style( 'ebHideStyleSheets' );
			wp_dequeue_style( 'fg-jquery-ui' );
		}

		function favicon() {
			echo '
            <link rel="shortcut icon" type="image/x-icon" href="' . esc_url( trailingslashit( $this->orig_theme_uri ) ) . 'favicon.ico" />
            <link rel="apple-touch-icon" href="' . esc_url( trailingslashit( $this->orig_theme_uri ) ) . '/customIcon.png" />
            <link rel="apple-touch-icon-precomposed" href="' . esc_url( trailingslashit( $this->orig_theme_uri ) ) . '/customIcon.png"/>
            ';
		}

		function eb_mobile_scripts() {
			global $post;

			add_action( 'wp_head', [ $this, 'tf_printTypeKitJs' ], 19 );
			wp_register_script(
				'eb-listing',
				plugins_url( '/js/listing.js', __FILE__ ),
				[ 'jquery' ],
				EB_MB_VERSION,
				true
			);
			wp_enqueue_script( 'eb-listing' );
			wp_localize_script( 'eb-listing', 'EbAjax', [
					'ajaxurl'  => admin_url( 'admin-ajax.php' ),
					'eb_nonce' => wp_create_nonce( 'eb-request-nonce' ),
				]
			);

			if ( ( isset( $post->eb_events_page_role ) && ( 'event_details' === $post->eb_events_page_role ) )
			     || ( isset( $post->post_content ) && ( ( false !== strpos( $post->post_content, '[eb_slider' ) )
			                                            || ( ( false !== strpos(
									$post->post_content,
									'[eb_carousel'
								) ) && ( false === strpos(
									$post->post_content,
									'template="carousel-desktop"'
								) ) ) ) ) ) {
				wp_register_script( 'js-swipe', plugins_url( '/js/swipe-2.0.js', __FILE__ ), '', '2.0', true );
				wp_enqueue_script( 'js-swipe' );
				if ( isset( $post->eb_events_page_role ) && ( 'event_details' !== $post->eb_events_page_role ) ) {
					add_action( 'wp_footer', [ $this, 'eb_slider_js_init' ] );
				}
			}

			if ( isset( $post->eb_events_page_role ) ) {
				if ( 'event_details' === $post->eb_events_page_role ) {
					wp_register_script(
						'eventbrite-mobile',
						plugins_url( '/js/mobile.js', __FILE__ ),
						[ 'jquery' ],
						EB_MB_VERSION,
						true
					);
					wp_enqueue_script( 'eventbrite-mobile' );
				} elseif ( 'calendar' === $post->eb_events_page_role ) {
					wp_register_style(
						'jquery-mobile-ui-mobile-style',
						plugins_url( '/css/blitzer/jquery-ui-1.8.4.custom.css', __FILE__ ),
						[],
						'1.8.4',
						'all'
					);
					wp_register_style(
						'jquery-mobile-ui-datepicker-mobile-style',
						plugins_url( '/css/jquery.ui.datepicker.mobile.css', __FILE__ ),
						[],
						'1.0a',
						'all'
					);
					wp_register_script(
						'jquery-ui-datepicker-mobile',
						plugins_url( '/js/jquery.ui.datepicker.mobile.js', __FILE__ ),
						[ 'jquery-ui-datepicker' ],
						'2.0',
						false
					);
					wp_register_script( 'eb-mobile-calendar', plugins_url( '/js/calendar.js', __FILE__ ), [
						'jquery',
						'jquery-ui-datepicker',
					], EB_MB_VERSION, true );
					wp_enqueue_script( 'eb-mobile-calendar' );
					wp_localize_script(
						'eb-mobile-calendar',
						'ajax_object',
						[
							'ajax_url' => admin_url( 'admin-ajax.php' ),
							'eb_none'  => wp_create_nonce( 'eb-request-nonce' ),
						]
					);
				}
			}
		}

		function addhttp( $url ) {
			if ( ! preg_match( "~^(?:f|ht)tps?://~i", $url ) ) {
				$url = "http://" . $url;
			}

			return $url;
		}

		/**
		 * Retrieves the options from the site meta table and sets any missing
		 * values to their defaults
		 *
		 * @return array of the mobile plugin options
		 * @author Marco Schmoecker
		 */
		function get_options() {
			$options = get_option( $this->settings_ref );
			$options = wp_parse_args( $options, $this->defaults );
			$options = sanitize_post( $options, 'db' );
			$options = array_intersect_key( $options, $this->defaults );

			return $options;
		}


		function query_vars( $vars ) {
			// We need to whitelist our query vars to ensure they're accessible to
			// other functions
			array_push( $vars, 'request' );    // request name

			return $vars;
		}

		function rewrite_rules_array( $rules ) {
			$newrules                                   = [];
			$newrules[ '(event|e)/([0-9]+)(/.+?)?/?$' ] = 'index.php?pagename=$matches[1]&$eb_id=$matches[2]&request=$matches[3]';
			$newrules[ '(search|calendar)/(.+?)?/?$' ]  = 'index.php?pagename=$matches[1]&request=$matches[2]';

			// prepend our rules ahead of WPs to ensure ours have priority
			$rules = $newrules + $rules;

			return $rules;
		}

		function tfly_tfcom_query_var( $public_query_vars ) {
			$public_query_vars[] = 'show';
			$public_query_vars[] = 'ids';

			return $public_query_vars;
		}

		function init() {
			add_filter( 'query_vars', [ $this, 'tfly_tfcom_query_var' ] );

			if ( isset( $_COOKIE[ 'eb_mobile' ] ) && $_COOKIE[ 'eb_mobile' ] === 'false' ) {
				add_action( 'wp_footer', 'eb_mobile_available' );
			}
			global $eb_mobileOptions;
			if ( ! empty( $eb_mobileOptions[ "desktop_destination_url" ] ) ) {
				add_action( 'wp_head', 'eb_mobile_desktop_redirect' );
			}

			if ( get_option( "eb_mobile_rewrite_done", null ) !== self::$svnVersion ) {
				global $wp_rewrite;
				$wp_rewrite->flush_rules();
				update_option( "eb_mobile_rewrite_done", self::$svnVersion );
			}

			global $eventbrite_music;
			$this->cms_settings = ( method_exists(
				$eventbrite_music,
				'get_options'
			) ) ? $eventbrite_music->get_options() : [];
		}

		function register_cpt_mobile_page() {

			$labels = [
				'name'               => _x( 'Mobile Pages', 'mobile_page' ),
				'singular_name'      => _x( 'mobile page', 'mobile_page' ),
				'add_new'            => _x( 'Add New', 'mobile_page' ),
				'add_new_item'       => _x( 'Add New Mobile Page', 'mobile_page' ),
				'edit_item'          => _x( 'Edit Mobile Page', 'mobile_page' ),
				'new_item'           => _x( 'New Mobile Page', 'mobile_page' ),
				'view_item'          => _x( 'View Mobile Page', 'mobile_page' ),
				'search_items'       => _x( 'Search Mobile Pages', 'mobile_page' ),
				'not_found'          => _x( 'No mobile pages found', 'mobile_page' ),
				'not_found_in_trash' => _x( 'No mobile pages found in Trash', 'mobile_page' ),
				'parent_item_colon'  => _x( 'Parent mobile page:', 'mobile_page' ),
				'menu_name'          => _x( 'Mobile Pages', 'mobile_page' ),
			];

			$args = [
				'labels'              => $labels,
				'hierarchical'        => false,
				'description'         => 'Eventbrite mobile pages',
				'supports'            => [
					'title',
					'editor',
					'author',
					'thumbnail',
					'custom-fields',
					'revisions',
					'page-attributes',
				],
				'public'              => false,
				'show_ui'             => true,
				'show_in_menu'        => true,
				'menu_position'       => 20,
				'menu_icon'           => 'tf-mobile-menu.png',
				'show_in_nav_menus'   => true,
				'publicly_queryable'  => true,
				'exclude_from_search' => true,
				'has_archive'         => false,
				'query_var'           => true,
				'can_export'          => true,
				'rewrite'             => [ 'with_front' => false, 'slug' => 'mobile-page' ],
				'capability_type'     => 'page',
			];

			register_post_type( 'mobile_page', $args );
		}

		function mobile_check() {
			if ( ! isset( $_SERVER[ "HTTP_USER_AGENT" ] ) || ( isset( $_COOKIE[ 'eb_mobile' ] ) && $_COOKIE[ 'eb_mobile' ] === 'false' ) ) {
				return false;
			}
			if ( isset( $_COOKIE[ 'eb_mobile' ] ) && $_COOKIE[ 'eb_mobile' ] === 'true' ) {  //phpcs:ignore
				return true;
			}

			return $this->device_check();
		}

		function device_check() {
			global $eb_mobileOptions;

			$detect     = new Mobile_Detect;
			$deviceType = ( $detect->isMobile() ? ( $detect->isTablet() ? 'tablet' : 'phone' ) : 'desktop' );

			$mobile = ( 'phone' !== $deviceType ) ? false : $deviceType;

			if ( ! empty( $eb_mobileOptions[ "desktop_destination_url" ] ) ) {
				if ( 'desktop' === $deviceType ) {
					$mobile = 'tablet';
				} else {
					$mobile = $deviceType;
				}
			}

			if ( isset( $_COOKIE[ 'eb_mobile' ] ) && $_COOKIE[ 'eb_mobile' ] === 'false' ) {
				$mobile = false;
			} elseif ( isset( $_COOKIE[ 'eb_mobile' ] ) && $_COOKIE[ 'eb_mobile' ] === 'true' ) {
				if ( 'desktop' === $deviceType ) {
					$mobile = 'tablet';
				} else {
					$mobile = $deviceType;
				}
			}

			return apply_filters( 'eb_mobile_device_check', $mobile );
		}

		function mobile_eb_cms_template( $template, $template_names ) {
			return $this->locate_template( $template_names );
		}

		function mobile_template( $theme ) {
			$theme_root     = get_theme_root( $theme );
			$stylesheet_dir = "$theme_root/$theme";

			if ( file_exists( $stylesheet_dir . '/mobile/index.php' ) ) {
				return $theme . '/mobile';
			} elseif ( defined( 'EB_MOBILE_THEME' ) ) {
				return apply_filters( 'eb_mobile_template', EB_MOBILE_THEME );
			}

			return $theme;
		}

		function mobile_stylesheet( $stylesheet ) {
			$theme_root     = get_theme_root( $stylesheet );
			$stylesheet_dir = "$theme_root/$stylesheet";

			if ( get_theme_mod( 'mobile_customizer_css' ) === false
			     && get_theme_mod( 'mobile_customizer_image' ) === false
			     && file_exists( $stylesheet_dir . '/mobile/style.css' ) ) {
				if ( file_exists( $stylesheet_dir . '/mobile/index.php' ) ) {
					return $stylesheet . '/mobile';
				} else {
					wp_register_style(
						'eb-mobile-venue',
						trailingslashit( get_theme_root_uri() ) . $stylesheet . '/mobile/style.css',
						[],
						'1',
						'all'
					);
				}
			}
			if ( defined( 'EB_MOBILE_THEME' ) ) {
				return apply_filters( 'eb_mobile_stylesheet', EB_MOBILE_THEME );
			}

			return $stylesheet;
		}

		function mobile_stylesheet_fixpath( $stylesheet_uri, $stylesheet_dir_uri = '' ) {

			if ( false !== strpos( $stylesheet_uri, 'themes/../plugins' ) ) {
				return str_replace( 'themes/../plugins', 'plugins', $stylesheet_uri );
			}

			return $stylesheet_uri;
		}

		function locate_template( $template_names, $load = false, $require_once = false ) {
			$located        = '';
			$stylesheetPath = get_stylesheet_directory();

			foreach ( (array) $template_names as $template_name ) {
				if ( ! $template_name ) {
					continue;
				}

				if ( file_exists( $stylesheetPath . '/eventbrite-mobile/' . $template_name . '.php' ) ) {
					$located = $stylesheetPath . '/eventbrite-mobile/' . $template_name . '.php';
					break;
				} elseif ( file_exists( dirname( __FILE__ ) . '/templates/' . $template_name . '.php' ) ) {
					$located = dirname( __FILE__ ) . '/templates/' . $template_name . '.php';
					break;
				}
			}

			$located = apply_filters( "eb_mobile_cms_template", $located );

			if ( $load && '' !== $located ) {
				if ( $require_once ) {
					require_once( $located );
				} else {
					require( $located );
				}
			}

			return $located;
		}

		// this does not appear to be in use
		function switch_page_template( $template ) {
			return $template;
		}

		function action_handler2( $content ) {

			if ( $content->query[ 'pagename' ] === 'venue' ) {
				include( ABSPATH . 'wp-content/plugins/eventbrite-mobile/venue.php' );
				die();
			}

			return $content;
		}

		function action_handler() {
			if ( ! isset( $_GET[ 'eb_mobile_action' ] ) ||
			     ! wp_verify_nonce( sanitize_text_field( $_GET[ 'eb_mobile_action' ] ), 'eb_mobile_nonce_action' )
			) {
				return;
			}
			global $eb_mobileOptions;
			$url    = wp_parse_url( get_bloginfo( 'home' ) );
			$domain = $url[ 'host' ];
			$path   = ( ! empty( $url[ 'path' ] ) ) ? $url[ 'path' ] : '/';

			$redirect = false;

			switch ( $_GET[ 'eb_mobile_action' ] ) {
				case 'reject_mobile':
					if ( empty( $eb_mobileOptions[ 'desktop_destination_url' ] ) ) {
						setcookie(
							'eb_mobile',
							'false',
							time() + 300000,
							$path,
							$domain
						);
					} else {
						setcookie(
							'eb_mobile_redirect',
							'false',
							time() + 300000,
							'',
							$domain
						);
					}
					$redirect = true;
					break;
				case 'show_mobile':
					setcookie(
						'eb_mobile',
						'true',
						time() + 300000,
						$path,
						$domain
					);
					$redirect = true;
					break;
				case 'tfly_who':
					if ( current_user_can( 'manage_options' ) ) {
						header( "Content-type: text/plain" );
						$user_agent = isset( $_SERVER[ 'HTTP_USER_AGENT' ] ) ? sanitize_text_field( $_SERVER[ 'HTTP_USER_AGENT' ] ) : 'unset';
						echo esc_html( sprintf( __( 'Browser: %s', 'tfly-mobile' ), $user_agent ) );
						die();
					}
					break;

			}
			if ( $redirect ) {
				if ( $eb_mobileOptions[ 'desktop_destination_url' ] ) {
					$go = $this->addhttp( $eb_mobileOptions[ 'desktop_destination_url' ] );
				} elseif ( ! empty( $_SERVER[ 'HTTP_REFERER' ] ) ) {
					$go = sanitize_text_field( $_SERVER[ 'HTTP_REFERER' ] );
				} else {
					$go = get_bloginfo( 'home' );
				}
				header( 'Location: ' . $go );
				die();
			}
		}

		function suppress_title( $title, $item_id ) {
			global $post;
			if ( ! is_admin() && isset( $post->ID ) && ( $item_id === $post->ID ) ) {
				return '';
			}

			return $title;
		}

		/**
		 * @return string
		 */
		function inline_legacy_logo_css() {
			global $wp_styles;
			$customizer_css   = get_theme_mod( 'mobile_customizer_css', '' );
			$customizer_image = get_theme_mod( 'mobile_customizer_image', '' );

			if ( ! empty( $customizer_image ) ) {
				$cropped_image_url = wp_get_attachment_image_src( $customizer_image, 'full' );
				if ( $cropped_image_url ) {
					$customizer_css .= 'header .brand {background-image: url("' . esc_url( $cropped_image_url[ 0 ] ) . '");}';
				}
			}

			if ( ! empty( $customizer_css ) || ! empty( $customizer_image ) ) {
				return '/* CUSTOMIZER CSS */ ' . $customizer_css;
			}

			if ( ! isset( $wp_styles->registered[ 'eb-mobile-venue' ] )
			     && isset( $this->orig_theme_dir ) && $this->orig_theme_dir
			     && isset( $this->orig_theme_uri ) && $this->orig_theme_uri
			     && file_exists( $this->orig_theme_dir . '/images/mobile-header.png' ) ) {
				return '/* LEGACY LOGO */ header .brand {background-image: url("' . esc_url( $this->orig_theme_uri ) . '/images/mobile-header.png");}';
			}

			return '';
		}

		/**
		 * Hook into the_posts to prepare and add API & other data to the $post object
		 *
		 * @param array $posts
		 *
		 * @return array $posts
		 * @author Marco Schmoecker
		 */
		function the_posts( $posts ) {
			global $wp_query;

			// the is_singular checks we only have one post but to ensure we don't
			// break if the indicies are not numerically indexed we still do a foreach loop
			if ( is_singular() ) :

				$params = [];

				// Handling exception in case $eb_id is empty. Otherwise pages end up rendering "empty" results.
				$settings = $this->get_options();

				if ( isset( $wp_query->query_vars[ 'eb_type' ] ) && ! empty( $wp_query->query_vars[ 'eb_type' ] ) ) {
					$id      = $wp_query->query_vars[ 'eb_id' ];
					$eb_type = $wp_query->query_vars[ 'eb_type' ];
				} else {
					if ( ! isset( $wp_query->query_vars[ 'eb_id' ] ) ) {
						if ( $settings[ 'venue_id' ] ) {
							$id = $settings[ 'venue_id' ];
						}
					} else {
						$id = $wp_query->query_vars[ 'eb_id' ];
					}
				}

				if ( $settings[ 'org_id' ] ) {
					$orgid = $params[ 'orgId' ] = $settings[ 'org_id' ];
				}

				foreach ( $posts as &$post ) :

					if ( is_page( 'venue' ) && ! isset( $eb_type ) ) {
						$post->eb_type = 'venue';
					}

					if ( ! isset( $post->eb_events_page_role ) ) {
						continue;
					}

					$post->eb_id       = $id;
					$post->tfly_org_id = $orgid;
					if ( $eb_type ) {
						$post->eb_type = $eb_type;
					}
					$max = $wp_query->query_vars[ 'num_results' ];

					if ( ! isset( $max ) ) {
						$max = 200;
					}

					switch ( $post->eb_events_page_role ) {

						case 'event_details':
							$params                   = [];
							$params[ 'organizer.id' ] = $settings[ 'org_id' ];
							$params[ 'event.id' ]     = isset( $post->eb_id ) ? $post->eb_id : $params[ 'event' ];
							$post->eb_event           = eventbrite_api::request( 'events', $params, 'destination' );

							$params[ 'description' ] = 'true';
							$params[ 'expand' ]      = '';
							$post->description       = eventbrite_api::request( 'events', $params, '' );

							break;

						case 'venue_details':
							$params[ 'venueId' ]    = $id;
							$params[ 'maxResults' ] = $max;
							break;
						case 'org_details':
							if ( isset( $wp_query->query_vars[ 'eb_id' ] ) ) {
								$params[ 'orgId' ] = $wp_query->query_vars[ 'eb_id' ];
							}
							$params[ 'maxResults' ] = $max;
							if ( ! isset( $post->eb_type ) ) {
								$post->eb_type = 'org';
							}
							break;
						case 'calendar':
							if ( $id ) {
								$params[ 'venueId' ] = $id;
							}
							$params[ 'maxResults' ] = $max;

							if ( ! strpos( $post->post_content, "richcalendar" ) ) {
								add_action( 'wp_enqueue_scripts', [ $this, 'tfly_scripts_jquery_richcal' ] );

								$tflyStyleFile = plugin_dir_path( __FILE__ ) . 'css/richcalendar.css';
								if ( file_exists( $tflyStyleFile ) ) {
									$ebStyleUrl = eb_plugin_dir_URL() . '/css/richcalendar.css';
									wp_register_style( 'tflyRichCalStyleSheets', $ebStyleUrl, false, '0.9' );
									wp_enqueue_style( 'tflyRichCalStyleSheets' );
								}

							}
							break;
						case 'listing':
							break;
					}
				endforeach;
			endif;

			return $posts;
		}


		/**
		 * Filter for shortcode: tf_mobile_tag
		 *
		 * @param string
		 *
		 * @return string (empty)
		 * @author Marco Schmoecker
		 */
		function eb_mobile_tag_filter( $content = null ) {
			return '';
		}

		/**
		 * Shortcode: tf_mobile
		 *
		 * @param array (see $atts below)
		 *
		 * @return string (buffer contents: execute shortcodes)
		 * @author Marco Schmoecker
		 */
		function eb_mobile_func( $atts, $content = null ) {
			$content = apply_filters( 'eb_mobile_tag', $content );

			return do_shortcode( $content );
		}

		/**
		 * Shortcode: eb_desktop
		 *
		 * @param array (see $atts below)
		 *
		 * @return string (buffer contents: execute shortcodes)
		 * @author Marco Schmoecker
		 */
		function eb_desktop_func( $atts, $content = null ) {
			$content = apply_filters( 'eb_desktop_tag', $content );

			return do_shortcode( $content );
		}

		/**
		 * Listing AJAX callback function
		 *
		 * @param array (see $atts below)
		 *
		 * @return string (buffer contents: JS init)
		 * @author Marco Schmoecker
		 */
		public function listing_ajax_func() {
			$re    = [];
			$nonce = isset( $_GET[ 'eb_nonce' ] ) ? sanitize_text_field( $_GET[ 'eb_nonce' ] ) : '';

			if ( false && ! wp_verify_nonce( $nonce, 'eb-request-nonce' ) ) {
				$re[ 'html' ]  = [];
				$re[ 'error' ] = 'Busted!';
				echo wp_json_encode( $re );
				die();
			}

			$feed_type = ( isset( $_GET[ 'feedType' ] ) && 'curated' !== $_GET[ 'feedType' ] && in_array(
					$_GET[ 'feedType' ],
					[ 'past', 'upcoming', 'current_future' ],
					true
				) )
				? sanitize_text_field( $_GET[ 'feedType' ] )
				: 'upcoming';

			$page_number = isset( $_GET[ 'pageNum' ] ) ? absint( $_GET[ 'pageNum' ] ) : 1;
			$num         = ( isset( $_GET[ 'maxNum' ] ) && ! empty( $_GET[ 'maxNum' ] ) ) ? absint( $_GET[ 'maxNum' ] ) : 20;

			$shortcode_type = isset( $_GET[ 'shortcodeType' ] ) ? sanitize_text_field( $_GET[ 'shortcodeType' ] ) : 'listview';
			$search_string  = isset( $_GET[ 'searchString' ] ) ? sanitize_text_field( $_GET[ 'searchString' ] ) : '';
			$exclude        = ( isset( $_GET[ 'exclude' ] ) )
				? explode( ',', sanitize_text_field( $_GET[ 'exclude' ] ) )
				: [];
			$dateformat     = ( isset( $_GET[ 'dateformat' ] ) ) ? sanitize_text_field( $_GET[ 'dateformat' ] ) : 'M j';
			$org_id         = ( isset( $_GET[ 'orgId' ] ) && ! empty( $_GET[ 'orgId' ] ) )
				? sanitize_text_field( $_GET[ 'orgId' ] )
				: $this->cms_settings[ 'org_id' ];

			add_filter( 'eb_template', [ $this, 'mobile_eb_cms_template' ], 10, 2 );

			$imagesize = 'square';
			$template  = 'list-view-item';

			if ( $shortcode_type === 'hero-listview' ) {
				$imagesize = 'xlarge1';
				$template  = 'heroListView-item';
			}

			$req = [];

			$req[ 'page' ] = $page_number;

			if ( isset( $this->cms_settings[ 'radio_filter_endpoint' ] ) ) {
				if ( 'venues' === $this->cms_settings[ 'radio_filter_endpoint' ] ) {
					$req[ 'venues' ] = $this->cms_settings[ 'venue_id' ];
				} else {
					$req[ 'organizers' ] = $this->cms_settings[ 'org_id' ];
				}
			}

			if ( isset( $_GET[ 'venueId' ] ) && ! empty( $_GET[ 'venueId' ] ) ) {
				$req[ 'venues' ] = explode( ',', sanitize_text_field( $_GET[ 'venueId' ] ) );
				unset( $req[ 'organizers' ] ); //You can't have both
			}

			if ( isset( $_GET[ 'orgId' ] ) && ! empty( $_GET[ 'orgId' ] ) ) {
				$req[ 'organizers' ] = explode( ',', sanitize_text_field( $_GET[ 'orgId' ] ) );
				unset( $req[ 'venues' ] ); //You can't have both
			}

			if ( isset( $_GET[ 'q' ] ) ) {
				$req[ 'q' ] = sanitize_text_field( $_GET[ 'q' ] );
			}

			$req[ 'order_by' ]    = 'start_asc';
			$req[ 'page_size' ]   = ( (int) $num >= 50 || $num === '0' ) ? 50 : (int) $num;
			$req[ 'time_filter' ] = 'current_future';
			$req[ 'expand' ]      = 'image,primary_organizer,venue,event_sales_status,ticket_availability,music_properties';

			$ebApiData = new Events_Api( $req );
			$ebApiData->request();

			ob_start();
			header( 'Content-Type: text/html' );

			if ( isset( $ebApiData->get_pagination()[ 'page_count' ] ) && ( $page_number <= $ebApiData->get_pagination()[ 'page_count' ] ) ) {
				foreach ( $ebApiData->get_events( true ) as $i => $event ) {
					$urlVars    = [];
					$urlVars    = eb_getInitialUrlVars( $event );
					$settings   = $this->cms_settings;
					$urlClasses = 'event-url';
					$settings   = $this->cms_settings;
					include 'inc/listView-values.php';
					$performers         = new Performers();
					$performancesMarkup = $performers->build_Listview_Performers( $event, false, $exclude );
					$templatePath       = eb_locate_template( $template );
					if ( ! empty( $templatePath ) && 0 === validate_file( $templatePath ) ) {
						require $templatePath;
					}
					$urlVars = null;
				}
			}

			if ( $page_number >= $ebApiData->get_pagination()[ 'page_count' ] ) { ?>
				<script language="JavaScript">
                    jQuery(document).ready(function ($) {
                        $('.list-view .loadMore').remove();
                        $('.hero-listview .loadMore').remove();
                    });
				</script>
			<?php }

			$re[ 'html' ] = ob_get_clean();
			echo $re[ 'html' ];

			die();
		}

		/**
		 * Calendar AJAX callback function
		 *
		 * @param array (see $atts below)
		 *
		 * @return string (buffer contents: JS init)
		 * @author Marco Schmoecker
		 */
		public function cal_ajax_func() {
			$nonce = isset( $_GET[ 'eb_nonce' ] ) ? sanitize_text_field( $_GET[ 'eb_nonce' ] ) : false;
			$re    = [];

			if ( false && ! wp_verify_nonce( $nonce, 'eb-request-nonce' ) ) {
				$re[ 'date' ]  = [];
				$re[ 'error' ] = 'Busted!';
				echo wp_json_encode( $re );
				die();
			}

			if ( ! isset( $_GET[ 'fromDate' ] ) || ! isset( $_GET[ 'fromDate' ] ) ) {
				$re[ 'date' ]  = [];
				$re[ 'error' ] = 'something went wrong ...';
				echo wp_json_encode( $re );
				die();
			}

			$exclude = isset( $_GET[ 'exclude' ] )
				? explode( ',', sanitize_text_field( $_GET[ 'exclude' ] ) )
				: [];

			$dateformat = ( isset( $_GET[ 'dateFormat' ] ) ) ? sanitize_text_field( $_GET[ 'dateFormat' ] ) : 'M j';

			$org_id = ( isset( $_GET[ 'orgId' ] ) && ! empty( $_GET[ 'orgId' ] ) )
				? sanitize_text_field( $_GET[ 'orgId' ] )
				: $this->cms_settings[ 'org_id' ];

			$page_number = isset( $_GET[ 'pageNum' ] ) ? absint( $_GET[ 'pageNum' ] ) : 1;

			add_filter( 'eb_template', [ $this, 'mobile_eb_cms_template' ], 10, 2 );
			$max_num = isset( $_GET[ 'maxNum' ] ) ? absint( $_GET[ 'maxNum' ] ) : 200;

			$req                  = [];
			$req[ 'order_by' ]    = 'start_asc';
			$req[ 'page_size' ]   = 50;
			$req[ 'time_filter' ] = 'current_future';
			$req[ 'expand' ]      = 'image,primary_organizer,venue,event_sales_status,ticket_availability,music_properties';

			if ( isset( $_GET[ 'venueId' ] ) && ! empty( $_GET[ 'venueId' ] ) ) {
				$req[ 'venues' ] = sanitize_text_field( $_GET[ 'venueId' ] );
			} elseif ( isset( $_GET[ 'orgId' ] ) && ! empty( $_GET[ 'orgId' ] ) ) {
				$req[ 'organizers' ] = sanitize_text_field( $_GET[ 'orgId' ] );
			} elseif ( isset( $this->cms_settings[ 'radio_filter_endpoint' ] ) && ( 'venues' === $this->cms_settings[ 'radio_filter_endpoint' ] ) ) {
				$req[ 'venues' ] = $this->cms_settings[ 'venue_id' ];
			} else {
				$req[ 'organizers' ] = $this->cms_settings[ 'org_id' ];
			}

			$req[ 'page' ] = $page_number;
			$ebApiData     = new Events_Api( $req );
			$ebApiData->request();
			$events = $ebApiData->get_events( true );

			$eventsBuild = [];
			foreach ( $events as $i => $event ) {
				if ( $event->hide_start_date ) {
					continue;
				}
				$urlVars  = [];
				$urlVars  = eb_getInitialUrlVars( $event );
				$settings = $this->cms_settings;
				include 'inc/listView-values.php';
				$performers         = new Performers();
				$performancesMarkup = $performers->build_Listview_Performers( $event, false, $exclude );
				ob_start();
				$templatePath = eb_locate_template( 'list-view-item' );
				if ( ! empty( $templatePath ) && 0 === validate_file( $templatePath ) ) {
					require $templatePath;
				}
				$event->markup = ob_get_clean();
				$eventsBuild[] = $event;
			}

			$re[ 'data' ] = $events;
			echo wp_json_encode( $re );
			die();
		}

		/**
		 * Shortcode: Slider JS init
		 *
		 * @param array (see $atts below)
		 *
		 * @return string (buffer contents: JS init)
		 * @author Marco Schmoecker
		 */
		function eb_slider_js_init() {
			?>

			<script type="text/javascript">
                // outside ready function so that buttons still have a var to attach function calls to like slider.next()
                //var slider;
                // I "think" that the problem is that somehow jquery mobile stops swipejs from detecting the width of the div (in the setup function)
                jQuery(document).ready(function ($) {
                    window.slider = new Swipe(document.getElementById('slider'), {
                        speed: 600,
                        auto: 6000,
                        continuous: true,
                        disableScroll: false
                        //stopPropagation: false
                    });
                });
			</script>
		<?php }


		/**
		 * Inject Type-Kit JS
		 *
		 * @param void
		 *
		 * @return void
		 * @author Marco Schmoecker
		 */
		function tf_printTypeKitJs() {
			$settings = $this->get_options();

			if ( isset( $settings[ "type_kit" ] ) && ( '' !== $settings[ "type_kit" ] ) ) {
				echo '
                <!-- BEGIN Typekit Fonts for WordPress -->
                ' . wp_kses( $settings[ "type_kit" ], [ 'style' => [], 'script' => [], 'link' => [] ] ) . '
                <!-- END Typekit Fonts for WordPress --->
                ';
			}
		}

		function admin_menu() {
			if ( class_exists( 'ticketfly_branding' ) ) {
				$icon = WP_PLUGIN_URL . '/ticketfly-branding/images/tflylogo-mini.png';
			} else {
				$icon = '';
			}
			if ( ! class_exists( 'eventbrite_music' ) ) {
				add_menu_page( 'Eventbrite Mobile', 'Eventbrite Mobile', 'manage_options', basename( __DIR__ ), [
					$this,
					'admin_menu_page',
				], $icon );
			} elseif ( function_exists( 'add_submenu_page' ) ) {
				add_submenu_page(
					'eb-events.php',
					__( 'Mobile', 'ticketfly' ),
					__( 'Mobile', 'ticketfly' ),
					'manage_options',
					basename( __DIR__ ),
					[
						$this,
						'admin_menu_page',
					]
				);

			}
		}


		/**
		 * Register and add settings
		 */
		public function admin_page_init() {
			register_setting(
				$this->settings_ref, // Option group
				$this->settings_ref, // Option name
				[ $this, 'sanitize' ] // Sanitize
			);

			add_settings_section(
				$this->settings_ref . '_general', // ID
				'', // Title
				[ $this, 'print_general_section_info' ], // Callback
				"{$this->settings_ref}_page" // Page
			);

			add_settings_field(
				'theme_color', // ID
				'Theme Color', // Title
				[ $this, 'theme_color_callback' ], // Callback
				"{$this->settings_ref}_page", // Page
				$this->settings_ref . '_general' // Section
			);

			add_settings_field(
				'type_kit',
				'Font Embed Code',
				[ $this, 'type_kit_callback' ],
				"{$this->settings_ref}_page",
				$this->settings_ref . '_general'
			);
		}

		/**
		 * Sanitize each setting field as needed
		 *
		 * @param array $input Contains all settings fields as array keys
		 */
		public function sanitize( $input ) {
			$new_input = [];
			if ( isset( $input[ 'theme_color' ] ) ) {
				$new_input[ 'theme_color' ] = sanitize_text_field( $input[ 'theme_color' ] );
			}

			if ( isset( $input[ 'desktop_destination_url' ] ) ) {
				$new_input[ 'desktop_destination_url' ] = esc_url_raw( $input[ 'desktop_destination_url' ] );
			}

			if ( isset( $input[ 'type_kit' ] ) ) {
				$new_input[ 'type_kit' ] =
					wp_kses(
						$input[ 'type_kit' ],
						[
							'script' => [],
							'a'      => [ 'href' ],
						]
					);
			}

			return $new_input;
		}

		/**
		 * Print the Section text
		 */
		public function print_general_section_info() {
			print 'Please configure the various settings in the area below.';
		}


		/**
		 * Get the settings option array and print one of its values
		 */
		public function theme_color_callback() {
			$eb_mobile_setting = $this->get_options();
			$themeColor        = isset( $eb_mobile_setting[ 'theme_color' ] ) ? $eb_mobile_setting[ 'theme_color' ] : '';
			printf(
				'<div><input id="%s[theme_color]" name="%s[theme_color]" type="radio" value="dark" %s> %s</div>',
				esc_attr( $this->settings_ref ),
				esc_attr( $this->settings_ref ),
				checked( $themeColor, 'dark', false ),
				esc_html__( 'Dark', 'eventbrite' )
			);
			printf(
				'<div><input id="%s[theme_color]" name="%s[theme_color]" type="radio" value="light" %s > %s</div>',
				esc_attr( $this->settings_ref ),
				esc_attr( $this->settings_ref ),
				checked( $themeColor, 'light', false ),
				esc_html__( 'Light', 'eventbrite' )
			);
			echo esc_html__( 'Theme Background Color', 'eventbrite' );
		}

		/**
		 * Get the settings option array and print one of its values
		 */
		public function desktop_destination_url_callback() {
			$eb_mobile_setting = $this->get_options();
			printf(
				'<input type="text" id="id_number" name="' . $this->settings_ref . '[desktop_destination_url]" value="%s" /> &nbsp; Enter the URL of your main site if you run it on a different domain.',
				( isset( $eb_mobile_setting[ 'desktop_destination_url' ] ) && $eb_mobile_setting[ 'desktop_destination_url' ] ) ? esc_attr( $eb_mobile_setting[ 'desktop_destination_url' ] ) : ''
			);
		}

		/**
		 * Get the settings option array and print one of its values
		 */
		public function type_kit_callback() {
			$eb_mobile_setting = $this->get_options();
			printf(
				'<textarea id="' . esc_attr( $this->settings_ref ) . '[type_kit]" name="' . esc_attr( $this->settings_ref ) . '[type_kit]" rows="5" cols="100">%s</textarea><br/>(TypeKit, Google Fonts, etc.)',
				( isset( $eb_mobile_setting[ 'type_kit' ] ) && $eb_mobile_setting[ 'type_kit' ] ) ? esc_html( $eb_mobile_setting[ 'type_kit' ] ) : ''
			);
		}

		/*************************************
		 * Admin Menu Page
		 *************************************/

		function admin_menu_page() {
			settings_errors();
			echo '<div class="wrap">
                <h2>Eventbrite Mobile Settings</h2>
                <form method="post" action="' . esc_url( admin_url( 'options.php' ) ) . '">';
			// This prints out all hidden setting fields
			settings_fields( $this->settings_ref );
			do_settings_sections( $this->settings_ref . "_page" );
			echo '<p class="submit">';
			submit_button( 'Save Settings', 'primary', 'save', false );
			echo '&nbsp;';
			echo '</p>
                </form>
            </div>'; ?>
			<div>
				<hr>
				<h3>Mobile Plugin Help</h3>
				<p>
					Detailed instructions &amp; options on the <a
							href="<?php echo esc_url( admin_url( 'admin.php?page=eb-events.php-help#mobile' ) ); ?>">Help
						page</a>
				</p>
			</div>
			<?php
		}
	}

	global $eventbrite_mobile;
	$eventbrite_mobile = new eventbrite_mobile();

endif;
