<?php
function tf_googleMaps( $venue ) {
	$lat_long   = $venue->lat . ',' . $venue->lng;
	$venueName  = $venue->name;
	$venueMapJS = '
//                  var map' . esc_js($venue->id) . ';
                  function initialize' . esc_js($venue->id) . '() {
                    var myLatlng = new google.maps.LatLng(' . wp_json_encode($lat_long) . ');
                    var myOptions = {
                      zoom: 15,
                      center: myLatlng,
                      mapTypeId: google.maps.MapTypeId.ROADMAP
                    };
                    map' .esc_js($venue->id) . ' = new google.maps.Map(document.getElementById("googlemap-' . esc_js($venue->id). '"),
                        myOptions);

                    var marker = new google.maps.Marker({
                          position: myLatlng,
                          title:' . wp_json_encode($venueName) . '
                      });

                      // To add the marker to the map, call setMap();
                      marker.setMap(map' . esc_js($venue->id) . ');
                  }

                  google.maps.event.addDomListener(window, "load", initialize' .esc_js($venue->id) . ');
';

	return $venueMapJS;
}


function print_venueInfo( $venueInfo, $atts ) {
	global $post;

	extract( wp_parse_args( $atts, [
		'title'    => 'Venue Information',
		'exclude'  => 'ical,gcal',
		'calshare' => 'true',
		'style'    => 'map',
	] ) );

	$exclude = explode( ",", $exclude );

	if ( isset( $post->eb_id ) && ( $post->eb_events_page_role === 'venue_details' ) ) { ?>

		<div id="tfly-venue-information">
			<?php if ( ! in_array( "title", $exclude, true ) ) { ?>
				<h2><?php echo esc_html( $title ); ?></h2>
			<?php } ?>
			<div class="tfly-venuedetails-metadata">
				<?php if ( eb_is_valid_field( $venueInfo->name ) && ! in_array( "venuename", $exclude, true ) ) { ?>
					<div class="tfly-venuedetails-venuename"><?php echo esc_html( $venueInfo->name ); ?></div>
				<?php }
				if ( eb_is_valid_field( $venueInfo->address1 ) && ! in_array( "address1", $exclude, true ) ) { ?>
					<div class="tfly-venuedetails-address1"><?php echo esc_html( $venueInfo->address1 ); ?></div>
				<?php }
				if ( eb_is_valid_field( $venueInfo->address2 ) && ! in_array( "address2", $exclude, true ) ) { ?>
					<div class="tfly-venuedetails-address2"><?php echo esc_html( $venueInfo->address2 ); ?></div>
				<?php }
				if ( eb_is_valid_field( $venueInfo->city ) && ! in_array( "city", $exclude, true ) ) { ?>
					<div class="tfly-venuedetails-city">
						<?php echo esc_html( $venueInfo->city ); ?>,
						<?php echo esc_html( $venueInfo->stateProvince ); ?>
						&nbsp;<?php echo esc_html( $venueInfo->postalCode ); ?>
					</div>
				<?php }
				if ( ! in_array( "googlemaps", $exclude, true ) && ( $venueInfo->address1 || $venueInfo->city ) ) {
					if ( 'map' === $style ) {
						$driving_directions_url = 'https://maps.google.com/maps?daddr=' . url_encode( $venueInfo->address1 . ', ' . $venueInfo->city . ', ' . $venueInfo->stateProvince . ' ' . $venueInfo->postalCode ); ?>
						<div class="tfly-venuedetails-map"
							 id="googlemap-<?php echo esc_attr( $venueInfo->id ); ?>">
						</div>
						<div class="tfly-venuedetails-directions">
							<a href="<?php echo esc_url( $driving_directions_url ); ?>" target="_blank">Driving Directions</a>
						</div>
						<?php global $venueInits;
						$venueInits = '<script type="text/javascript">' . tf_googleMaps( $venueInfo ) . '</script>';
						add_action( 'wp_footer', 'tfly_injectGMapsJS' );
					} else {
						$googleMapsAddress = $venueInfo->address1 . ", " . $venueInfo->city . ", " . $venueInfo->stateProvince . " " . $venueInfo->postalCode; ?>
						<div class="tfly-venuedetails-googlemap">
							<a href="<?php echo esc_url( 'https://maps.google.com/?q=' . $googleMapsAddress ); ?>">
								Google Map
							</a>
						</div>
					<?php }
				}
				if ( eb_is_valid_field( $venueInfo->url ) && ! in_array( "url", $exclude, true ) ) { ?>
					<div class="tfly-venuedetails-url">
						<a href="<?php echo esc_url( $venueInfo->url ); ?>">Venue Website</a>
					</div>
				<?php }

				$calLink = get_bloginfo( 'home' ) . eb_URL( 'ical', $post->eb_id, $post->eb_events_page_role );

				if ( false && ! in_array( "ical", $exclude, true ) ) { ?>
					<a class="tfly-ical" href="<?php echo esc_url( $calLink ); ?>">iCal</a>
				<?php }

				if ( false && ! in_array( "gcal", $exclude, true ) ) { ?>
					<a class="tfly-gcal"
					   href="<?php echo esc_url( 'https://www.google.com/calendar/render?cid=' . rawurlencode( $calLink ) ); ?>"
					   target="_blank">Google Calendar</a>
				<?php }
				?>
			</div>

		</div>
		<?php
	}
}
